Struct AvifEncoder

struct AvifEncoder<W> { ... }

AVIF Encoder.

Writes one image into the chosen output.

Implementations

impl<W: Write> AvifEncoder<W>

fn new(w: W) -> Self

Create a new encoder that writes its output to w.

fn new_with_speed_quality(w: W, speed: u8, quality: u8) -> Self

Create a new encoder with a specified speed and quality that writes its output to w. speed accepts a value in the range 1-10, where 1 is the slowest and 10 is the fastest. Slower speeds generally yield better compression results. quality accepts a value in the range 1-100, where 1 is the worst and 100 is the best.

fn with_colorspace(self: Self, color_space: ColorSpace) -> Self

Encode with the specified color_space.

fn with_num_threads(self: Self, num_threads: Option<usize>) -> Self

Configures rayon thread pool size. The default None is to use all threads in the default rayon thread pool.

impl<T> Any for AvifEncoder<W>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AvifEncoder<W>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AvifEncoder<W>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for AvifEncoder<W>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Pointable for AvifEncoder<W>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T, U> Into for AvifEncoder<W>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AvifEncoder<W>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AvifEncoder<W>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<W> Freeze for AvifEncoder<W>

impl<W> RefUnwindSafe for AvifEncoder<W>

impl<W> Send for AvifEncoder<W>

impl<W> Sync for AvifEncoder<W>

impl<W> Unpin for AvifEncoder<W>

impl<W> UnsafeUnpin for AvifEncoder<W>

impl<W> UnwindSafe for AvifEncoder<W>

impl<W: Write> ImageEncoder for AvifEncoder<W>

fn write_image(self: Self, data: &[u8], width: u32, height: u32, color: ExtendedColorType) -> ImageResult<()>

Encode image data with the indicated color type.

The encoder currently requires all data to be RGBA8, it will be converted internally if necessary. When data is suitably aligned, i.e. u16 channels to two bytes, then the conversion may be more efficient.