Struct image::codecs::ico::IcoEncoder[−][src]

pub struct IcoEncoder<W: Write> { /* fields omitted */ }

ICO encoder

Implementations

impl<W: Write> IcoEncoder<W>[src]

pub fn new(w: W) -> IcoEncoder<W>[src]

Create a new encoder that writes its output to w.

pub fn encode(
    self,
    data: &[u8],
    width: u32,
    height: u32,
    color: ColorType
) -> ImageResult<()>
[src]

Encodes the image image that has dimensions width and height and ColorType c. The dimensions of the image must be between 1 and 256 (inclusive) or an error will be returned.