Struct image::codecs::tiff::TiffEncoder[−][src]

pub struct TiffEncoder<W> { /* fields omitted */ }

Encoder for tiff images

Implementations

impl<W: Write + Seek> TiffEncoder<W>[src]

pub fn new(w: W) -> TiffEncoder<W>[src]

Create a new encoder that writes its output to w

pub fn encode(
    self,
    data: &[u8],
    width: u32,
    height: u32,
    color: ColorType
) -> ImageResult<()>
[src]

Encodes the image image that has dimensions width and height and ColorType c.

16-bit types assume the buffer is native endian.