Function load_from_memory_with_format

fn load_from_memory_with_format(buf: &[u8], format: ImageFormat) -> ImageResult<DynamicImage>

Create a new image from a byte slice

This is just a simple wrapper that constructs an std::io::Cursor around the buffer and then calls load with that reader.

Try ImageReader for more advanced uses.