Struct Rect

struct Rect { ... }

A Rectangle defined by its top left corner, width and height.

Fields

x: u32

The x coordinate of the top left corner.

y: u32

The y coordinate of the top left corner.

width: u32

The rectangle's width.

height: u32

The rectangle's height.

Implementations

impl Clone for Rect

fn clone(self: &Self) -> Rect

impl Copy for Rect

impl Debug for Rect

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Rect

impl Freeze for Rect

impl Hash for Rect

fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)

impl PartialEq for Rect

fn eq(self: &Self, other: &Rect) -> bool

impl RefUnwindSafe for Rect

impl Send for Rect

impl StructuralPartialEq for Rect

impl Sync for Rect

impl Unpin for Rect

impl UnsafeUnpin for Rect

impl UnwindSafe for Rect

impl<T> Any for Rect

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Rect

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Rect

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Rect

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Rect

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Pointable for Rect

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T> ToOwned for Rect

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Rect

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Rect

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Rect

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>