Struct Frames

struct Frames<'a> { ... }

An implementation dependent iterator, reading the frames as requested

Implementations

impl<'a> Frames<'a>

fn new(iterator: Box<dyn Iterator<Item = ImageResult<Frame>> + 'a>) -> Self

Creates a new Frames from an implementation specific iterator.

fn collect_frames(self: Self) -> ImageResult<Vec<Frame>>

Steps through the iterator from the current frame until the end and pushes each frame into a Vec. If en error is encountered that error is returned instead.

Note: This is equivalent to Frames::collect::<ImageResult<Vec<Frame>>>()

impl Iterator for Frames<'_>

fn next(self: &mut Self) -> Option<ImageResult<Frame>>

impl<'a> Freeze for Frames<'a>

impl<'a> RefUnwindSafe for Frames<'a>

impl<'a> Send for Frames<'a>

impl<'a> Sync for Frames<'a>

impl<'a> Unpin for Frames<'a>

impl<'a> UnsafeUnpin for Frames<'a>

impl<'a> UnwindSafe for Frames<'a>

impl<'data, I> IntoParallelRefMutIterator for Frames<'a>

fn par_iter_mut(self: &'data mut Self) -> <I as IntoParallelRefMutIterator<'data>>::Iter

impl<I> IntoIterator for Frames<'a>

fn into_iter(self: Self) -> I

impl<I> ParallelIterator for Frames<'a>

impl<T> Any for Frames<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Frames<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Frames<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Frames<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Itertools for Frames<'a>

impl<T> Pointable for Frames<'a>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T, U> Into for Frames<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Frames<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Frames<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>