Trait ConvertBuffer

trait ConvertBuffer<T>

Provides color conversions for whole image buffers.

Required Methods

fn convert(self: &Self) -> T

Converts self to a buffer of type T

A generic implementation is provided to convert any image buffer to a image buffer based on a Vec<T>.

Implementors