Trait ConvertBuffer
trait ConvertBuffer<T>
Provides color conversions for whole image buffers.
Required Methods
fn convert(self: &Self) -> TConverts
selfto a buffer of type TA generic implementation is provided to convert any image buffer to a image buffer based on a
Vec<T>.
Implementors
impl<Container, FromType: Pixel, ToType> ConvertBuffer for ImageBuffer<FromType, Container>