Struct BmpDecoder

struct BmpDecoder<R> { ... }

A bmp decoder

Implementations

impl<R: BufRead + Seek> BmpDecoder<R>

fn new(reader: R) -> ImageResult<BmpDecoder<R>>

Create a new decoder that decodes from the stream r

fn new_without_file_header(reader: R) -> ImageResult<BmpDecoder<R>>

Create a new decoder that decodes from the stream r without first reading a BITMAPFILEHEADER. This is useful for decoding the CF_DIB format directly from the Windows clipboard.

fn set_indexed_color(self: &mut Self, indexed_color: bool)

If true, the palette in BMP does not apply to the image even if it is found. In other words, the output image is the indexed color.

fn get_palette(self: &Self) -> Option<&[[u8; 3]]>

Get the palette that is embedded in the BMP image, if any.

impl<R> Freeze for BmpDecoder<R>

impl<R> RefUnwindSafe for BmpDecoder<R>

impl<R> Send for BmpDecoder<R>

impl<R> Sync for BmpDecoder<R>

impl<R> Unpin for BmpDecoder<R>

impl<R> UnsafeUnpin for BmpDecoder<R>

impl<R> UnwindSafe for BmpDecoder<R>

impl<R: BufRead + Seek> ImageDecoder for BmpDecoder<R>

fn dimensions(self: &Self) -> (u32, u32)
fn color_type(self: &Self) -> ColorType
fn read_image(self: Self, buf: &mut [u8]) -> ImageResult<()>
fn read_image_boxed(self: Box<Self>, buf: &mut [u8]) -> ImageResult<()>

impl<R: BufRead + Seek> ImageDecoderRect for BmpDecoder<R>

fn read_rect(self: &mut Self, x: u32, y: u32, width: u32, height: u32, buf: &mut [u8], row_pitch: usize) -> ImageResult<()>

impl<T> Any for BmpDecoder<R>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for BmpDecoder<R>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for BmpDecoder<R>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for BmpDecoder<R>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Pointable for BmpDecoder<R>

unsafe fn init(init: <T as Pointable>::Init) -> usize
unsafe fn deref<'a>(ptr: usize) -> &'a T
unsafe fn deref_mut<'a>(ptr: usize) -> &'a mut T
unsafe fn drop(ptr: usize)

impl<T, U> Into for BmpDecoder<R>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for BmpDecoder<R>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for BmpDecoder<R>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>