Enum PnmSubtype
enum PnmSubtype
Denotes the category of the magic number
Variants
-
Bitmap(SampleEncoding) Magic numbers P1 and P4
-
Graymap(SampleEncoding) Magic numbers P2 and P5
-
Pixmap(SampleEncoding) Magic numbers P3 and P6
-
ArbitraryMap Magic number P7
Implementations
impl PnmSubtype
fn magic_constant(self: Self) -> &'static [u8; 2]Get the two magic constant bytes corresponding to this format subtype.
fn sample_encoding(self: Self) -> SampleEncodingWhether samples are stored as binary or as decimal ascii
impl Clone for PnmSubtype
fn clone(self: &Self) -> PnmSubtype
impl Copy for PnmSubtype
impl Debug for PnmSubtype
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for PnmSubtype
impl Freeze for PnmSubtype
impl PartialEq for PnmSubtype
fn eq(self: &Self, other: &PnmSubtype) -> bool
impl RefUnwindSafe for PnmSubtype
impl Send for PnmSubtype
impl StructuralPartialEq for PnmSubtype
impl Sync for PnmSubtype
impl Unpin for PnmSubtype
impl UnsafeUnpin for PnmSubtype
impl UnwindSafe for PnmSubtype
impl<T> Any for PnmSubtype
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for PnmSubtype
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for PnmSubtype
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for PnmSubtype
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for PnmSubtype
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Pointable for PnmSubtype
unsafe fn init(init: <T as Pointable>::Init) -> usizeunsafe fn deref<'a>(ptr: usize) -> &'a Tunsafe fn deref_mut<'a>(ptr: usize) -> &'a mut Tunsafe fn drop(ptr: usize)
impl<T> ToOwned for PnmSubtype
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for PnmSubtype
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for PnmSubtype
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for PnmSubtype
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>