Trait EncodableLayout
trait EncodableLayout: seals::EncodableLayout
Types which are safe to treat as an immutable byte slice in a pixel layout for image encoding.
Required Methods
fn as_bytes(self: &Self) -> &[u8]Get the bytes of this value.
Implementors
impl EncodableLayout for [u8]impl EncodableLayout for [u16]impl EncodableLayout for [f32]